@@ -120,9 +120,10 @@ def fit_report_as_dict(inpars: minimize, modelpars: dict = None) -> dict:
                     buffer["correlations"][name_1][name_2] = par.correl[name_2]
     try:
         for i, name_1 in enumerate(parnames):
-            buffer["covariance_matrix"][name_1] = {}
-            for j, name_2 in enumerate(parnames):
-                buffer["covariance_matrix"][name_1][name_2] = result.covar[i, j]
+            buffer["covariance_matrix"][name_1] = {
+                name_2: result.covar[i, j] for j, name_2 in enumerate(parnames)
+            }
+
     except (AttributeError, IndexError) as exc:
         print(f"{exc}: Covariance Matrix could not be calculated.\n")
     return buffer
