@@ -295,6 +295,7 @@ class PostProcessing:
             $$
             \mathrm{residual}_{i} = \mathrm{model}_{i} - \mathrm{data}_{i}
             $$
+            $$
             \mathrm{residual}_{avg} = \frac{ \sum_{i}
                 \mathrm{model}_{i} - \mathrm{data}_{i}}{i}
             $$
@@ -465,7 +466,7 @@ def read_input_file(fname: str) -> MutableMapping[str, Any]:
         fname (str): Name of the input file.
 
     Raises:
-        SystemExit: If the input file is not supported.
+        OSError: If the input file is not supported.
 
     Returns:
         dict: Return the input file arguments as a dictionary with additional
@@ -483,7 +484,7 @@ def read_input_file(fname: str) -> MutableMapping[str, Any]:
         with open(_fname, "r") as f:
             args = yaml.load(f, Loader=yaml.FullLoader)
     else:
-        raise SystemExit(
+        raise OSError(
             f"ERROR: Input file {fname} has not supported file format.\n"
             "Supported fileformats are: '*.json', '*.yaml', and '*.toml'"
         )
@@ -530,3 +531,23 @@ def load_data(args: Dict[str, str]) -> pd.DataFrame:
     except ValueError as exc:
         print(f"Error: {exc} -> Dataframe contains non numeric data!")
         sys.exit(1)
+
+
+def check_keywords_consistency(
+    check_args: MutableMapping[str, Any], ref_args: Dict[str, Any]
+) -> None:
+    """Check if the keywords are consistent.
+
+    Check if the keywords are consistent between two dictionaries. The two dictionaries
+    are reference keywords of the `cmd_line_args` and the `args` of the `input_file`.
+
+    Args:
+        check_args (MutableMapping[str, Any]): First dictionary to be checked.
+        ref_args (Dict[str,Any]): Second dictionary to be checked.
+
+    Raises:
+        KeyError: If the keywords are not consistent.
+    """
+    for key in check_args:
+        if key not in ref_args.keys():
+            raise KeyError(f"ERROR: The {key} is not parameter of the `cmd-input`!")
